# ---------------------------------------------------------------------------
# ---------------------------------------------------------------------------
#
#              ===========================================
#                     Skamp Project Setup Script
#              ===========================================
#
# A csh/tcsh shell script to setup the env vars soft links and aliases for
# the execution of the SkampProject build applications.
#
# ---------------------------------------------------------------------------
# ---------------------------------------------------------------------------


# ----------------------------------------
# User Warning about correct shell to use:
# ----------------------------------------

# Warn user that this script fails if not sourced from a csh or tcsh shell
echo Current shell is $0. Must use tcsh or csh otherwise script will fail.
# The next line will force a failure if not csh or tcsh
if ( "0" == "1" ) goto done


# ----------------------------
# Tell user what we are doing:
# ----------------------------
echo 
echo "           ===================================="
echo "            Setting up the SkampDP environment "
echo "           ===================================="
echo 

# ----------------------------------------
# Get the SkampDP Home Directory Location:
# ----------------------------------------

# Get the directory that this shell script is in by looking up the last command
# called in the history which should contain either the relative or absolute
# pathname of this script file. Note, if this shell scripts was called with
# arguments then we need to calculate the position of the shell script pathname
# in the last history line.
set last_history_line=`history | tail -1`
# Calculate the index containing the shell script
@ idx = ${#last_history_line} - ${#argv}
set script_name=$last_history_line[${idx}]
set dirname=`dirname $script_name`
# Directory path specified may be relative in which case we prefix with the 
# working directory [pwd] to make it absolute.
if ( $dirname !~ /* ) then
   set dirname=`pwd`/$dirname
endif
# For the sake of tidiness remove any redundant "/." in the path with "/"
# we do this via the sed substitute command.
set dirname=`echo $dirname | sed "s#/\.##"`
# Now we have our SKAMP HOME DIRECTORY
set SKAMP_HOME_DIR=$dirname
echo SkampDP Home located at ${SKAMP_HOME_DIR}

# --------------------------------------------
# Get the required SkampDP build version and 
# make sure that it is soft linked to build:
# --------------------------------------------

# To make things easier we temporarily move to the Skamp Home Directory
pushd . > /dev/null
cd ${SKAMP_HOME_DIR}
set use_build
# Get the list of build directories in this directory
# (theses are directories of name build-[verno]
set build_lst=`ls -td build-*/`
if ( ${#argv} == 0 ) then ; # Use default build
   if (  -e build ) set use_build=build
   if (! -e build ) set use_build=${build_lst[1]}
else ; # User specified a build so use it if it exists
   if ( -e $1       ) set use_build=$1
   if ( -e build-$1 ) set use_build=build-$1
endif
# If failed to find a build then give an error message and abort
if ( ${use_build} == "" ) then
   echo Error! Cannot find build.
   goto done
endif
# Get rid of any double back slashes in the build name
set use_build=`echo ${use_build} | sed "s#//##"`
# Set a link from the required build version to the directory "build" if needed
if ( ${use_build} != "build" ) then 
   rm -rdf build
   ln -s ${use_build} build
endif
echo Using `file ${use_build}`
# Now return to the original directory
popd > /dev/null


# ---------------------------------------------------------
# Define all directory locations that we need for SkampDP:
#------------- --------------------------------------------

# All executables will be in a subdirectory build
# Archive data assumed to be in directory ~/SkampData (soft linked)
# Output data directory assumed to be in directory ~/SkampOut (soft linked)
set build_dir=build
set skampdata_dir=$SKAMP_HOME_DIR/SkampData
set skampout_dir=$SKAMP_HOME_DIR/SkampOut


# -----------------------------------------------------------
# Check that the Skamp Data Directories exist
# -----------------------------------------------------------

if ( ! -e $skampdata_dir ) then
   echo Cannot locate Skamp Data Directory $skampdata_dir
   goto done
endif
if ( ! -e $skampout_dir ) then
   set skampdata_dir=.
endif


# ----------------------------------------------
# Now setup the enviromental variables required:
# ----------------------------------------------

# Location for the SKAMP input data
setenv SKAMPENV_INPDATA_DIR $skampdata_dir

# Location to place the SKAMP output data
setenv SKAMPENV_OUTDATA_DIR $skampout_dir

# Location for the SKAMP Instrument data
setenv SKAMPENV_INSTRDATA_DIR $SKAMP_HOME_DIR/build

# Location for the PGPLOT binaries required for the runtime plots
setenv SKAMPENV_PGPLOT_BIN $SKAMP_HOME_DIR/build

# Location for the MIRIAD Tasks
setenv SKAMPENV_MIRIADTASKS_DIR $SKAMP_HOME_DIR/build

# Location for the SKAMP Tasks
setenv SKAMPENV_SKAMPTASKS_DIR $SKAMP_HOME_DIR/build

# Location for the SKAMP Scripts
setenv SKAMPENV_SKAMPSCRIPTS_DIR $SKAMP_HOME_DIR/build

# A default input file if none is given at the command line (testing purposes)
setenv SKAMPENV_DEFAULT_RAW SRC2152-699_070808.vis


# ----------------------
# Now setup the aliases:
# ----------------------
alias skampacp ${SKAMPENV_SKAMPSCRIPTS_DIR}/skampacp
alias gaina    ${SKAMPENV_SKAMPSCRIPTS_DIR}/gaina

# -------------------------------
# Inform the user of the aliases:
# -------------------------------
echo
echo 'The following skamp commands have been setup:'
echo
echo '       skampacp ~ To run the Skamp Archive Data Control Panel '
echo '       gaina    ~ To run the gain profile analysis tool'
echo
done:
